@@ -4,7 +4,7 @@ Class containing all TI-Rover commands. Used for debugging
 from ti_python_module.err import withConsole as err
 from ti_python_module.err import onlyCheck as cerr
 from ti_python_module.file_handler import create_log as log
-
+import random as rng
 
 ###########################################################################################
 
@@ -18,7 +18,7 @@ def text_at(line: int, text: str, align: str):
         align (str): The texts alignment. Possible Options: 'left', 'center', 'right'.
 
     Returns:
-        list: list: list: a list containing the following data: [line, text, align]
+        None: None
     """
 
     if cerr.type_error(int, line) == False: log("Argument 'line' has to be type integer!", "ERROR", "TI Hub", "Text At")
@@ -36,7 +36,7 @@ def text_at(line: int, text: str, align: str):
 
     log("Showing text '" + text + "' at line " + str(line) + " with alignment '" + align + "'", "INFO", "TI Hub", "Text At")
     print("Showing text '" + text + "' at line " + str(line) + " with alignment '" + align + "'")
-    return [text, line, align]
+    return None
 
 
 ###########################################################################################
@@ -49,7 +49,7 @@ def sleep(seconds: float):
         seconds (float): The amount of seconds to wait.
 
     Returns:
-        list: a list containing the following data: [seconds]
+        None: None
     """
     if cerr.type_error(float, seconds) == False: log("Argument 'seconds' has to be type float!", "ERROR", "TI Hub", "Sleep")
 
@@ -61,7 +61,7 @@ def sleep(seconds: float):
 
     log("Waiting for '" + str(seconds) + "' seconds", "INFO", "TI Hub", "Sleep")
     print("Waiting for " + str(seconds) + " seconds")
-    return [seconds]
+    return None
 
 
 ###########################################################################################
@@ -106,7 +106,7 @@ def forward(distance:float, distance_unit:str = None, speed:float = None, speed_
         ValueError: If the speed is set, but not the speed unit.
 
     Returns:
-        list: a list containing the following values: [distance, distance_unit, speed, speed_unit]
+        None: None
     """
     if(distance_unit == None and speed == None and speed_unit == None):
         if cerr.type_error(float, distance) == False: log("Argument 'distance' has to be type float!", "ERROR", "TI Rover", "Forward")
@@ -117,7 +117,7 @@ def forward(distance:float, distance_unit:str = None, speed:float = None, speed_
 
         log("Moving the Rover forward by '" + str(distance) + "'", "INFO", "TI Rover", "Forward")
         print("Moving Rover forward by '" + str(distance) + "'")
-        return [distance, distance_unit, speed, speed_unit]
+        return None
 
     elif(distance_unit != None and speed == None and speed_unit == None):
 
@@ -133,7 +133,7 @@ def forward(distance:float, distance_unit:str = None, speed:float = None, speed_
 
         log("Moving the rover forward by '" + str(distance) + " " + distance_unit + "'", "INFO", "TI Rover", "Forward")
         print("Moving Rover forward by '" + str(distance) + " " + distance_unit + "'")
-        return [distance, distance_unit, speed, speed_unit]
+        return None
 
     elif(distance_unit != None and speed != None and speed_unit != None):
 
@@ -158,7 +158,7 @@ def forward(distance:float, distance_unit:str = None, speed:float = None, speed_
 
         log("Moving the Rover forward by '" + str(distance) + " " + distance_unit + "' with a speed of '" + str(speed) + " " + speed_unit + "'", "INFO", "TI Rover", "Forward")
         print("Moving Rover forward by '" + str(distance) + " " + distance_unit + "' with a speed of '" + str(speed) + " " + speed_unit + "'")
-        return [distance, distance_unit, speed, speed_unit]
+        return None
 
     else:
         raise ValueError("ERROR: You have to set both 'speed' and 'speed_unit' in order to set one of these!")
@@ -181,7 +181,7 @@ def backward(distance:float, distance_unit:str = None, speed:float = None, speed
         ValueError: If the speed is set, but not the speed unit.
 
     Returns:
-        list: a list containing the following values: [distance, distance_unit, speed, speed_unit]
+        None: None
     """
     if(distance_unit == None and speed == None and speed_unit == None):
         if cerr.type_error(float, distance) == False: log("Argument 'distance' has to be type float!", "ERROR", "TI Rover", "Backward")
@@ -192,7 +192,7 @@ def backward(distance:float, distance_unit:str = None, speed:float = None, speed
 
         log("Moving the Rover backwards by '" + str(distance) + "'", "INFO", "TI Rover", "Backward")
         print("Moving Rover backwards by '" + str(distance) + "'")
-        return [distance, distance_unit, speed, speed_unit]
+        return None
 
     elif(distance_unit != None and speed == None and speed_unit == None):
 
@@ -208,7 +208,7 @@ def backward(distance:float, distance_unit:str = None, speed:float = None, speed
 
         log("Moving the rover backwards by '" + str(distance) + " " + distance_unit + "'", "INFO", "TI Rover", "Backward")
         print("Moving Rover backwards by '" + str(distance) + " " + distance_unit + "'")
-        return [distance, distance_unit, speed, speed_unit]
+        return None
 
     elif(distance_unit != None and speed != None and speed_unit != None):
 
@@ -233,7 +233,7 @@ def backward(distance:float, distance_unit:str = None, speed:float = None, speed
 
         log("Moving the Rover backwards by '" + str(distance) + " " + distance_unit + "' with a speed of '" + str(speed) + " " + speed_unit + "'", "INFO", "TI Rover", "Backward")
         print("Moving Rover backwards by '" + str(distance) + " " + distance_unit + "' with a speed of '" + str(speed) + " " + speed_unit + "'")
-        return [distance, distance_unit, speed, speed_unit]
+        return None
 
     else:
         raise ValueError("ERROR: You have to set both 'speed' and 'speed_unit' in order to set one of these!")
@@ -248,7 +248,7 @@ def left(degrees:float):
         degrees (float): The angle to turn left.
 
     Returns:
-        list: a list containing the following data: [degrees]
+        None: None
     """
 
     if cerr.type_error(float, degrees) == False: log("Argument 'degrees' has to be type float", "ERROR", "TI Rover", "Left")
@@ -256,7 +256,7 @@ def left(degrees:float):
 
     log("Turning the rover left by '" + str(degrees) + "' degrees", "INFO", "TI Rover", "Left")
     print("Turning rover left by '" + str(degrees) + "' degrees")
-    return [degrees]
+    return None
 
 ###########################################################################################
 
@@ -268,7 +268,7 @@ def right(degrees:float):
         degrees (float): The angle to turn right.
 
     Returns:
-        list: a list containing the following data: [degrees]
+        None: None
     """
 
     if cerr.type_error(float, degrees) == False: log("Argument 'degrees' has to be type float", "ERROR", "TI Rover", "Right")
@@ -276,7 +276,7 @@ def right(degrees:float):
 
     log("Turning the rover right by '" + str(degrees) + "' degrees", "INFO", "TI Rover", "Right")
     print("Turning rover right by '" + str(degrees) + "' degrees")
-    return [degrees]
+    return None
 ###########################################################################################
 
 def stop():
@@ -326,7 +326,7 @@ def stay(time:int=30):
         time (int, optional): The time to stay. Defaults to 30.
 
     Returns:
-        list: a list containing the following data: [time]
+        None: None
     """
 
     if cerr.type_error(int, time) == False: log("Argument 'time' has to be type integer!", "ERROR", "TI Rover", "Stay")
@@ -337,7 +337,7 @@ def stay(time:int=30):
 
     log("Staying at the current location for '" + str(time) + "' seconds", "INFO", "TI Rover", "Stay")
     print("Rover stays at current location for '" + str(time) + "' seconds")
-    return [time]
+    return None
 
 ###########################################################################################
 
@@ -350,7 +350,7 @@ def to(x:float, y:float):
         y (float): The y coordinate to go to.
     
     Returns:
-        list: a list containing the following data: [x, y]
+        None: None
     """
     if cerr.type_error(float, x) == False: log("Argument 'x' has to be type float!", "ERROR", "TI Rover", "To")
     if cerr.type_error(float, y) == False: log("Argument 'y' has to be type float!", "ERROR", "TI Rover", "To")
@@ -360,7 +360,7 @@ def to(x:float, y:float):
 
     log("Moving the rover to ( " + str(x) + " | " + str(y) + " ) on the virtual grid", "INFO", "TI Rover", "To")
     print("Rover moves to '(" + str(x) + " | " + str(y) + ")' on the virtual grid.")
-    return [x, y, x*10, y*10]
+    return None
 
 ###########################################################################################
 
@@ -373,7 +373,7 @@ def to_polar(radius:float, theta_degrees:float):
         theta_degrees (float): The angle to move to.
 
     Returns:
-        list: a list containing the following values: [radius, theta_degrees]
+        None: None
     """
     if cerr.type_error(float, radius) == False: log("Argument 'radius' has to be type float!", "ERROR", "TI Rover", "To Polar")
     if cerr.type_error(float, theta_degrees) == False: log("Argument 'theta_degrees' has to be type float!", "ERROR", "TI Rover", "To Polar")
@@ -383,7 +383,7 @@ def to_polar(radius:float, theta_degrees:float):
 
     log("Moving the Rover to polar with a radius of '" + str(radius) + "' and an angle of '" + str(theta_degrees) + "' degrees", "INFO", "TI Rover", "To Polar")
     print("Rover moves to polar with radius '" + str(radius) + "' and '" + str(theta_degrees) + "' degrees")
-    return [radius, theta_degrees]
+    return None
 
 ###########################################################################################
 
@@ -396,7 +396,7 @@ def to_angle(degrees:float, unit:str):
         unit (str): The unit to spin. Possible Options: 'degrees', 'radians', 'gradians'.
 
     Returns:
-        list: a list containing the following data: [degrees, unit]
+        None: None
     """
     if cerr.type_error(float, degrees) == False: log("Argument 'degrees' has to be type float!", "ERROR", "TI Rover", "To Angle")
     if cerr.type_error(str, unit) == False: log("Argument 'unit' has to be type string!", "ERROR", "TI Rover", "To Angle")
@@ -412,7 +412,7 @@ def to_angle(degrees:float, unit:str):
     
     log("Turning the rover by " + str(degrees) + " '" + unit + "'", "INFO", "TI Rover", "To Angle")
     print("Rover turns by angle '" + str(degrees) + "' with unit type '" + unit + "' degrees")
-    return [degrees, unit]
+    return None
 
         
 ###########################################################################################
@@ -427,7 +427,7 @@ def backward_time(time:float, speed:float = 1, unit:str = "units/s"):
         unit (str, optional): The unit of speed. Possible Options: 'units/s', 'm/s', 'revs/s'. Defaults to "units/s".
 
     Returns:
-        list: a list containing the following data: [time, speed, unit]
+        None: None
     """
     if cerr.type_error(float, time) == False: log("Argument 'time' has to be type float!", "ERROR", "TI Rover", "Backward Time")
     if cerr.type_error(float, speed) == False: log("Argument 'speed' has to be type float!", "ERROR", "TI Rover", "Backward Time")
@@ -445,7 +445,7 @@ def backward_time(time:float, speed:float = 1, unit:str = "units/s"):
 
     log("Moving the rover backwards for '" + str(time) + "' seconds with a speed of " + str(speed) + " '" + unit + "'", "INFO", "TI Rover", "Backward Time")
     print("Moving the rover backwards for '" + str(time) + "' seconds with a speed of '" + str(speed) + unit + "'")
-    return [time, speed, unit]
+    return None
 
 
 ###########################################################################################
@@ -460,7 +460,7 @@ def forward_time(time:float, speed:float = 1, unit:str = "units/s"):
         unit (str, optional): The unit of speed. Possible Options: 'units/s', 'm/s', 'revs/s'. Defaults to "units/s".
 
     Returns:
-        list: a list containing the following data: [time, speed, unit]
+        None: None
     """
     if cerr.type_error(float, time) == False: log("Argument 'time' has to be type float!", "ERROR", "TI Rover", "Forward Time")
     if cerr.type_error(float, speed) == False: log("Argument 'speed' has to be type float!", "ERROR", "TI Rover", "Forward Time")
@@ -478,7 +478,7 @@ def forward_time(time:float, speed:float = 1, unit:str = "units/s"):
 
     log("Moving the rover forwards for '" + str(time) + "' seconds with a speed of " + str(speed) + " '" + unit + "'", "INFO", "TI Rover", "Forward Time")
     print("Moving the rover forwards for '" + str(time) + "' seconds with a speed of '" + str(speed) + unit + "'")
-    return [time, speed, unit]
+    return None
     
 
 ###########################################################################################
@@ -510,11 +510,12 @@ def colour_measurement():
         9 = white    
     
     Returns
-        None: None
+        int: The number of the colour dominant
     """
     log("Measuring the dominant colour from the colour sensor", "INFO", "TI Rover", "Colour Measurement")
     print("Measuring dominant colour from colour sensor")
-    return None
+    retValue = rng.randint(1, 9)
+    return retValue
 
 ###########################################################################################
 
@@ -523,11 +524,12 @@ def red_measurement():
     Returns a value between 0 and 255 that indicates the perceived red level being seen by the color input sensor.
     
     Returns
-        None: None
+        int: The red level measured
     """
     log("Measuring red level from the colour sensor", "INFO", "TI Rover", "Red Measurement")
     print("Measuring red level from the colour sensor")
-    return None
+    retValue = rng.randint(0, 255)
+    return retValue
 
 ###########################################################################################
 
@@ -536,11 +538,12 @@ def green_measurement():
     Returns a value between 0 and 255 that indicates the perceived green level being seen by the color input sensor.
     
     Returns
-        None: None
+        int: The green level measured
     """
     log("Measuring green level from the colour sensor", "INFO", "TI Rover", "Green Measurement")
     print("Measuring green level from the colour sensor")
-    return None
+    retValue = rng.randint(0, 255)
+    return retValue
 
 ###########################################################################################
 
@@ -549,11 +552,12 @@ def blue_measurement():
     Returns a value between 0 and 255 that indicates the perceived blue level being seen by the color input sensor.
     
     Returns
-        None: None
+        int: The blue level measured
     """
     log("Measuring blue level from the colour sensor", "INFO", "TI Rover", "Blue Measurement")
     print("Measuring blue level from the colour sensor")
-    return None
+    retValue = rng.randint(0, 255)
+    return retValue
 
 ###########################################################################################
 
@@ -562,11 +566,12 @@ def gray_measurement():
     Returns a value between 0 and 255 that indicates the perceived gray level being seen by the color input sensor with 0 being black and 255 being white.
     
     Returns
-        None: None
+        int: The gray level measured
     """
     log("Measuring gray level from the colour sensor", "INFO", "TI Rover", "Gray Measurement")
     print("Measuring gray level from the colour sensor")
-    return None
+    retValue = rng.randint(0, 255)
+    return retValue
 
 ###########################################################################################
 
@@ -575,11 +580,14 @@ def encoders_gyro_measurement():
     Returns a list of values that contains the left and right wheel encoder counts as well as the current gyro heading.
     
     Returns
-        None: None
+        tuple (float, float, int): The left wheels encoder, the right wheels encoder, the gyroscope
     """
     log("Measuring the gyroscope values for heading, left wheel and right wheel", "INFO", "TI Rover", "Encoders Gyroscope Measurement")
     print("Measuring gyroscope values for heading, left wheel and right wheel")
-    return None
+    retLeftWheel = rng.randint(100, 1000000) / 100
+    retRightWheel = rng.randint(100, 1000000) / 100
+    retGyro = rng.randint(0, 359)
+    return retLeftWheel, retRightWheel, retGyro
 
 ###########################################################################################
 
@@ -588,11 +596,12 @@ def gyro_measurement():
     Returns a value that represents the current gyro reading, including drift, in the degrees.
     
     Returns
-        None: None
+        int: The value measured by the gyroscope
     """
     log("Getting the values measured by the gyroscope", "INFO", "TI Rover", "Gyroscope Measurement")
     print("Measuring gyroscope values")
-    return None
+    retValue = rng.randint(0, 359)
+    return retValue
 
 ###########################################################################################
 
@@ -606,7 +615,7 @@ def colour_rgb(red:float, green:float, blue:float):
         blue (int): The blue value (0 - 255).
 
     Returns:
-        list: a list containing the following data: [red, green, blue]
+        None: None
     """
 
     if cerr.type_error(int, red) == False: log("Argument 'red' has to be type integer!", "ERROR", "TI Rover", "Colour RGB")
@@ -629,7 +638,7 @@ def colour_rgb(red:float, green:float, blue:float):
         
     log("Setting RGB-Led to '" + str(red) + "' red, '" + str(green) + "' green , '" + str(blue) + "' blue", "INFO", "TI Rover", "Colour RGB")
     print("Setting RGB-Led to Red: " + str(red) + ", Green: " + str(green) + ", Blue: " + str(blue))
-    return [red, green, blue]
+    return None
 
 ###########################################################################################
 
@@ -642,7 +651,7 @@ def blink(frequency: float, time: float):
         time (float): The time to blink in seconds. Ranges from 0.1 to 100.
 
     Returns:
-        list: a list containing the following data: [frequency, time, total_blinks]
+        None: None
     """
 
     if cerr.type_error(float, frequency) == False: log("Argument 'frequency' has to be type integer!", "ERROR", "TI Rover", "Blink")
@@ -659,7 +668,7 @@ def blink(frequency: float, time: float):
 
     log("Blinking the RGB-LED at a frequency of '" + str(frequency) + "' Hz for a time of '" + str(time) + "' seconds (" + str(time * frequency) + ") times", "INFO", "TI Rover", "Blink")
     print("Blinking the RGB-LED at a frequency of " + str(frequency) + "Hz for " + str(time) + " seconds (" + str(time * frequency) + ") times")
-    return [frequency, time, time * frequency]
+    return None
 
 ###########################################################################################
 
@@ -686,7 +695,7 @@ def motor_left(speed:int, time:float = 5):
         time (float, optional): The time to spin. Ranges from 0.1 to 100. Defaults to 5.
 
     Returns:
-        list: a list containing the following data: [speed, time]
+        None: None
     """
     if cerr.type_error(int, speed) == False: log("Argument 'speed' has to be type integer!", "ERROR", "TI Rover", "Left Motor")
     if cerr.type_error(float, time) == False: log("Argument 'time' has to be type float!", "ERROR", "TI Rover", "Left Motor")
@@ -700,7 +709,7 @@ def motor_left(speed:int, time:float = 5):
     
     log("Setting the left motor to counter-clockwise with a speed of '" + str(speed) + "' for a time of '" + str(time) + "' seconds", "INFO", "TI Rover", "Left Motor")
     print("Setting the left motor power to 'speed " + str(speed) + "' for a time of '" + str(time) + " seconds'")
-    return [float(speed), time]
+    return None
 
 ###########################################################################################
 
@@ -713,7 +722,7 @@ def motor_right(speed:int, time:float = 5):
         time (float, optional): The time to spin. Ranges from 0.1 to 100. Defaults to 5.
 
     Returns:
-        list: a list containing the following data: [speed, time]
+        None: None
     """
     if cerr.type_error(int, speed) == False: log("Argument 'speed' has to be type integer!", "ERROR", "TI Rover", "Right Motor")
     if cerr.type_error(float, time) == False: log("Argument 'time' has to be type float!", "ERROR", "TI Rover", "Right Motor")
@@ -727,7 +736,7 @@ def motor_right(speed:int, time:float = 5):
     
     log("Setting the right motor to counter-clockwise with a speed of '" + str(speed) + "' for a time of '" + str(time) + "' seconds", "INFO", "TI Rover", "Right Motor")
     print("Setting the right motor power to 'speed " + str(speed) + "' for a time of '" + str(time) + " seconds'")
-    return [float(speed), time]
+    return None
 
 ###########################################################################################
 
@@ -743,7 +752,7 @@ def motors(left_direction:str, left_speed:int, right_direction:str, right_speed:
         time (float, optional): The time to spin the wheels. Defaults to 5.
 
     Returns:
-        list: a list containing the following data: [left_direction, left_speed, right_direction, right_speed, time]
+        None: None
     """
     if cerr.type_error(str, left_direction) == False: log("Argument 'left_direction' has to be type string!", "ERROR", "TI Rover", "Motors")
     if cerr.type_error(int, left_speed) == False: log("Argument 'left_speed' has to be type integer!", "ERROR", "TI Rover", "Motors")
@@ -775,7 +784,7 @@ def motors(left_direction:str, left_speed:int, right_direction:str, right_speed:
     
     log("Setting the left motor to rotate '" + left_direction + "' with a speed of '" + str(left_speed) + "'. Setting the right motor to rotate '" + right_direction + "' with a speed of '" + str(right_speed) + "'. Both motors are running for '" + str(time) + "' seconds", "INFO", "TI Rover", "Motors")
     print("Setting the left motor to rotate '" + left_direction + "' with a speed of '" + str(left_speed) + "'. Setting the right motor to rotate '" + right_direction + "' with a speed of '" + str(right_speed) + "'. Both motors are running for '" + str(time) + " seconds'")
-    return [left_direction, left_speed, right_direction, right_speed, time]
+    return None
 
 
 ###########################################################################################
@@ -785,11 +794,17 @@ def waypoint_xythdrn():
     Reads the x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions, command number of the current waypoint. Returns a list with all these values as elements.
     
     Returns:
-        None: None
+        list (float): The x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions and command number of the current waypoint
     """
     log("Fetching the x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions and command number of the current waypoint", "INFO", "TI Rover", "Waypoint Xythdrn")
     print("Fetching the x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions and command number of the current waypoint")
-    return None
+    retXCoord = rng.randint(-1000, 1000) / 10
+    retYCoord = rng.randint(-1000, 1000) / 10
+    retTime = rng.randint(1, 1000) / 10
+    retWheelRevs = rng.randint(1, 150000) / 100
+    retCmdNum = rng.randint(0, 100)
+    retList:list = [retXCoord, retYCoord, retTime, retWheelRevs, retCmdNum]
+    return retList
 
 ###########################################################################################
 
@@ -798,11 +813,18 @@ def waypoint_prev():
     Reads the x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions, command number of the previous waypoint.
 
     Returns:
-        None: None
+        list (float): The x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions and command number of the previous waypoint
     """
     log("Fetching the x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions and command number of the previous waypoint", "INFO", "TI Rover", "Waypoint Previous")
     print("Fetching the x-coord, y-coord, time, heading, distance traveled, number of wheel revolutions and command number of the previous waypoint")
-    return None
+    retXCoord = rng.randint(-1000, 1000) / 10
+    retYCoord = rng.randint(-1000, 1000) / 10
+    retTime = rng.randint(1, 1000) / 10
+    retWheelRevs = rng.randint(1, 150000) / 100
+    retCmdNum = rng.randint(0, 100)
+    retList:list = [retXCoord, retYCoord, retTime, retWheelRevs, retCmdNum]
+    return retList
+
 
 ###########################################################################################
 
@@ -811,11 +833,12 @@ def waypoint_eta():
     Fetches the estimated time to drive to a waypoint.
     
     Returns:
-        None: None
+        int: The estimated time of arrival of the next waypoint
     """
     log("Fetching estimated time to reach the next waypoint", "INFO", "TI Rover", "Waypoint ETA")
     print("Fetching estimated time to reach next waypoint")
-    return None
+    retValue = rng.randint(1, 100)
+    return retValue
 
 ###########################################################################################
 
@@ -824,11 +847,12 @@ def path_done():
     Returns a value of 0 or 1 depending on whether the Rover is moving (0) or finished with all movement (1).
     
     Returns:
-        None: None
+        int: 0 ==> Rover is moving ; 1 ==> Rover is done
     """
     log("Checking if the rover is done with the current path", "INFO", "TI Rover", "Path Done")
     print("Checking if the rover is done with it's path")
-    return None
+    retValue = rng.choice([1, 0])
+    return retValue
 
 ###########################################################################################
 
@@ -837,11 +861,14 @@ def pathlist_x():
     Returns a list of X values from the beginning to and including the current Waypoint X value.
     
     Returns:
-        None: None
+        list (float): The list of x values of the waypoints from the beginning
     """
     log("Fetching the x values of the previous and current waypoints", "INFO", "TI Rover", "Pathlist X")
     print("Fetching x values of previous and current waypoints")
-    return None
+    retList:list[float] = []
+    for i in range(rng.randint(1, 11)):
+        retList.append(rng.randint(-200, 200) / 10)
+    return retList
 
 ###########################################################################################
 
@@ -850,11 +877,14 @@ def pathlist_y():
     Returns a list of y values from the beginning to and including the current Waypoint Y value.
     
     Returns:
-        None: None
+        list (float): The list of y values of the waypoints from the beginning
     """
     log("Fetching the y values of the previous and current waypoints", "INFO", "TI Rover", "Pathlist Y")
     print("Fetching y values of previous and current waypoints")
-    return None
+    retList:list[float] = []
+    for i in range(rng.randint(1, 11)):
+        retList.append(rng.randint(-200, 200) / 10)
+    return retList
 
 ###########################################################################################
 
@@ -863,11 +893,14 @@ def pathlist_time():
     Returns a list of the time in seconds from the beginning to and including the current Waypoint time value.
     
     Returns:
-        None: None
+        list (float): The list of the time needed to reach the waypoints from the beginning
     """
     log("Fetching the time passed since the first waypoint", "INFO", "TI Rover", "Pathlist Time")
     print("Fetching time since first waypoint")
-    return None
+    retList:list[float] = []
+    for i in range(rng.randint(1, 11)):
+        retList.append(rng.randint(-500, 500) / 10)
+    return retList
 
 ###########################################################################################
 
@@ -876,11 +909,14 @@ def pathlist_heading():
     Returns a list of the headings from the beginning to and including the current Waypoint heading value.
     
     Returns:
-        None: None
+        list (float): The list of headings needed to reach the waypoints from the beginning
     """
     log("Fetching the headings since the fist waypoint", "INFO", "TI Rover", "Pathlist Heading")
     print("Fetching headings since first waypoint")
-    return None
+    retList:list[float] = []
+    for i in range(rng.randint(1, 11)):
+        retList.append(rng.randint(0, 359))
+    return retList
 
 ###########################################################################################
 
@@ -889,11 +925,14 @@ def pathlist_distance():
     Returns a list of the distances traveled from the beginning to and including the current Waypoint distance value.
 
     Returns:
-        None: None
+        list (float): The list of distances traveled to reach the waypoints from the beginning
     """
     log("Fetching the distances traveled since the first waypoint", "INFO", "TI Rover", "Pathlist Distance")
     print("Fetching distances traveled since first waypoint")
-    return None
+    retList:list[float] = []
+    for i in range(rng.randint(1, 11)):
+        retList.append(rng.randint(1, 500) / 10)
+    return retList
 
 ###########################################################################################
 
@@ -902,11 +941,14 @@ def pathlist_revs():
     Returns a list of the number of revolutions traveled from the beginning to and including the current Waypoint revolutions value.
     
     Returns:
-        None: None
+        list (float): The list of wheel revolutions needed to reach the waypoints from the beginning
     """
     log("Fetching the number of wheel revolutions since the first waypoint", "INFO", "TI Rover", "Pathlist Revolutions")
     print("Fetching wheel revolutions since first waypoint")
-    return None
+    retList:list[float] = []
+    for i in range(rng.randint(1, 11)):
+        retList.append(rng.randint(1, 2000) / 10)
+    return retList
 
 ###########################################################################################
 
@@ -915,11 +957,14 @@ def pathlist_cmdnum():
     Returns a list of command numbers for the path.
     
     Returns:
-        None: None
+        list (float): The list of command numbers for the path
     """
     log("Fetching list of waypoints numbers since the first waypoint", "INFO", "TI Rover", "Pathlist CMDNUM")
     print("Fetching list of waypoint numbers since first waypoint")
-    return None
+    retList:list[float] = []
+    for i in range(rng.randint(1, 11)):
+        retList.append(i)
+    return retList
 
 ###########################################################################################
 
@@ -928,11 +973,12 @@ def waypoint_x():
     Returns x coordinate of current waypoint.
     
     Returns:
-        None: None
+        float: The x coordinate of the current waypoint
     """
     log("Fetching the x coordinate of the current waypoint", "INFO", "TI Rover", "Waypoint X")
     print("Fetching x coordinate of current waypoint")
-    return None
+    retValue:float = rng.randint(-200, 200) / 10
+    return retValue
 
 ###########################################################################################
 
@@ -941,11 +987,12 @@ def waypoint_y():
     Returns y coordinate of current waypoint.
     
     Returns:
-        None: None
+        float: The y coordinate of the current waypoint
     """
     log("Fetching the y coordinate of the current waypoint", "INFO", "TI Rover", "Waypoint Y")
     print("Fetching y coordinate of current waypoint")
-    return None
+    retValue:float = rng.randint(-200, 200) / 10
+    return retValue
 
 ###########################################################################################
 
@@ -954,11 +1001,12 @@ def waypoint_time():
     Returns time spent traveling from previous to current waypoint.
     
     Returns:
-        None: None
+        float: The time needed travelling from the previous waypoint
     """
     log("Fetching the time spent travelling to the current waypoint", "INFO", "TI Rover", "Waypoint Time")
     print("Fetching time spent travelling to current waypoint")
-    return None
+    retValue = rng.randint(-500, 500) / 10
+    return retValue
 
 ###########################################################################################
 
@@ -967,11 +1015,12 @@ def waypoint_heading():
     Returns absolute heading of current waypoint.
     
     Returns:
-        None: None
+        float: The absolute heading
     """
     log("Fetching the absolute heading of the current waypoint", "INFO", "TI Rover", "Waypoint Heading")
     print("Fetching absolute heading of current waypoint")
-    return None
+    retValue = rng.randint(0, 359)
+    return retValue
 
 ###########################################################################################
 
@@ -980,11 +1029,12 @@ def waypoint_distance():
     Returns distance traveled between previous and current waypoint.
     
     Returns:
-        None: None
+        float: The distance traveled since the lsat waypoint
     """
     log("Fetching the distance traveled between the current and the previous waypoint", "INFO", "TI Rover", "Waypoint Distance")
     print("Fetching distance traveled between current and previous waypoint")
-    return None
+    retValue = rng.randint(1, 500) / 10
+    return retValue
 
 ###########################################################################################
 
@@ -993,8 +1043,9 @@ def waypoint_revs():
     Returns number of revolutions needed to travel between previous and current waypoint.
     
     Returns:
-        None: None
+        float: The number of wheel revolutions since the last waypoint
     """
     log("Fetching the wheel revolutions since the last waypoint", "INFO", "TI Rover", "Waypoint Revolutions")
     print("Fetching wheel revolutions since last waypoint")
-    return None
\ No newline at end of file
+    retValue = rng.randint(1, 2000) / 10
+    return retValue
\ No newline at end of file
